/*------------------------------------------------------------------------------
 *
 * Calculate_Cauchy() - Called from Menu_E() -
 *                      1. Calculates the refractive index of a material at the
 *                         given wavelength using the Cauchy equation.
 *                      2. Displays the refractive index and the given wavelength
 *                         to the screen.  The display is stopped from scrolling
 *                         to allow the user to read the results - the return
 *                         key must be pressed to continue.
 *
 *------------------------------------------------------------------------------
 */

#include "opt_cal.h"
Calculate_Cauchy(C1,C2,C3,Lambda)
double C1;       /* material specific values for Cauchy equation */
double C2;
double C3;
double Lambda;   /* wavelength of light                          */
{
  char x;        /* dummy scanning variable                      */
  double n;      /* calculated refractive index                  */

  extern double sqr();
  extern Report_Error();

  Lambda = Lambda/1000;

  n = C1 + C2/sqr(Lambda) + C3/sqr(sqr(Lambda));

  if     ( n < 1.0 || n > 3.0 ) Report_Error(17);
  else
   {
     printf("\n\tThe refractive index (n) = %.4f\n",n);
     printf("\tat the specified wavelength of %.4f microns.\n",Lambda);
     fflush(stdin);
     printf("\nPress 'Return' to continue\n\n");
     scanf("%c", &x);
   }

}/*END Calculate_Cauchy */
/*-----------------------------------------------------------------------------*/
