/*------------------------------------------------------------------------------
 *
 * Calculate_EEpOT() - Called from Menu_F() -
 *                     1.  Calls Report_Error() if the input data will result in
 *                         a negative square root or zero denomiator.
 *                     2.  Calculates the value of Epsilon, Epsilon Prime, Omega,
 *                         or Theta depending on the value of Fchoice.
 *                     3.  When the calculation is complete, the values of all
 *                         variables are diplayed to the screen.  The display is
 *                         stopped from scrolling to allow the user to read the
 *                         results - the return key must be pressed to continue.
 *
 *------------------------------------------------------------------------------
 */

#include "opt_cal.h"
Calculate_EEpOT(Epsilon,Epsilon_P,Omega,Theta,Fchoice)
double Epsilon;     /* long axis of ellipsoid                        */
double Epsilon_P;   /* radius of ellipsoid at angle Theta            */
double Omega;       /* short axis of ellipsoid                       */
double Theta;       /* angle between Epsilon and and Epsilon Prime   */
char Fchoice;       /* determines variable to be solved for          */
{
  char x;                      /* dummy scanning variable            */
  int ErrorFlag = 0;
  double Radian = 57.29577951; /* conversion from degrees to radians */
  double Temp1;                /* temporary variables                */
  double Temp2;

  extern double sqr();
  extern Report_Error();
  switch(Fchoice)
  {
    case '1' : if( (sqr(Omega) - sqr(Epsilon_P)*sqr(sin(Theta/Radian))) <= 0)
                 {
                   Report_Error(21);
                   ErrorFlag = 1;
                 }
               else Epsilon =
                    sqrt(
                          sqr(Epsilon_P) * sqr(Omega) * sqr(cos(Theta/Radian)) /
                         (sqr(Omega) - sqr(Epsilon_P) * sqr(sin(Theta/Radian)))
                        );
               break;

    case '2' : Epsilon_P = Omega * Epsilon /
                           sqrt(
                                sqr(Omega)   * sqr(cos(Theta/Radian)) +
                                sqr(Epsilon) * sqr(sin(Theta/Radian))
                               );
               break;

    case '3' : if( (sqr(Epsilon) - sqr(Epsilon_P)*sqr(cos(Theta/Radian))) < 0 )
                 {
                   Report_Error(22);
                   ErrorFlag = 1;
                 }
               else Omega =
                    sqrt(
                         sqr(Epsilon_P) * sqr(Epsilon)   * sqr(sin(Theta/Radian)) /
                         (sqr(Epsilon)  - sqr(Epsilon_P) * sqr(cos(Theta/Radian)))
                        );
               break;

    case '4' : Temp1 = sqr(Omega) - sqr(Epsilon);
               Temp2 = (sqr(Omega)*sqr(Epsilon)/sqr(Epsilon_P)) - sqr(Epsilon);

               if( Temp1 == 0 || Temp2/Temp1 < 0)
                 {
                   Report_Error(23);
                   ErrorFlag = 1;
                 }
               else Theta = Radian * acos(sqrt( Temp2/Temp1 ));
               break;

  }/*END SWITCH*/
  if(ErrorFlag != 1)
   {
     printf("\n\tEpsilon        = %.4f\n", Epsilon);
     printf("\tEpsilon Prime  = %.4f\n", Epsilon_P);
     printf("\tOmega          = %.4f\n", Omega);
     printf("\tTheta          = %.2f\n", Theta);
     fflush(stdin);
     printf("\nPress 'Return' to continue\n\n");
     scanf("%c", &x);
   }
}/*END Calculate_EEpOT */
/*-----------------------------------------------------------------------------*/
