/*------------------------------------------------------------------------------
 *
 * Calculate_Fresnel() - Called from Menu_D() -
 *                       1. Calls Report_Error() if the input data results in an
 *                          undefined 'Theta_tran' or a zero denominator for any
 *                          of the equations.
 *                       2. Calculates Rp, Rs, and L (see below) if no errors
 *                          were detected.
 *                       3. If there were no errors, the values of Rp, Rs and L
 *                          are displayed to the screen.  The display is
 *                          stopped from scrolling to allow the user to read the
 *                          results - the return key must be pressed to continue.
 *
 *------------------------------------------------------------------------------
 */

#include "opt_cal.h"
Calculate_Fresnel(N_incd,N_tran,Theta_incd,Alpha)
double N_incd;         /* incident material refractive index                  */
double N_tran;         /* transmitting material refractive index              */
double Theta_incd;     /* angle of incident light                             */
double Alpha;          /* angle between incident light and reflected light    */
{
  char x;                        /* dummy scanning variable                   */
  int ErrorFlag = 0;
  double Radian = 57.29577951;   /* conversion from degees to radians         */

  double Theta_tran;             /* transmitting material refractive index    */
  double Rp;                     /* amplitude of reflected light in 'p' state */
  double Rs;                     /* amplitude of reflected light in 's' state */
  double L;                      /* reflected light intensity in percent      */

  extern double sqr();
  extern Report_Error();


  if( N_incd < N_tran )
    Theta_tran = Radian *
                 asin( N_incd*sin(Theta_incd/Radian) /
                       N_tran
                     );
   else if( N_incd >= N_tran  && Theta_incd <= Radian*asin(N_tran/N_incd)  )
    Theta_tran = Radian *
                 asin( N_incd*sin(Theta_incd/Radian) /
                       N_tran
                     );
   else
    {
      Report_Error(13);
      ErrorFlag = 1;
    }
  if( (N_incd * cos(Theta_tran/Radian) + N_tran * cos(Theta_incd/Radian)) == 0 )
   {
     Report_Error(14);
     ErrorFlag = 1;
   }
  else Rp = (N_tran * cos(Theta_incd/Radian) - N_incd * cos(Theta_tran/Radian)) /
            (N_incd * cos(Theta_tran/Radian) + N_tran * cos(Theta_incd/Radian));



  if( (N_incd*cos(Theta_incd/Radian) + N_tran*cos(Theta_tran/Radian)) == 0 )
   {
     Report_Error(15);
     ErrorFlag = 1;
   }
  else Rs = (N_incd * cos(Theta_incd/Radian) - N_tran * cos(Theta_tran/Radian)) /
            (N_incd * cos(Theta_incd/Radian) + N_tran * cos(Theta_tran/Radian));


  L = ( sqr(Rp)*sqr(cos(Alpha/Radian)) + sqr(Rs)*sqr(sin(Alpha/Radian)) ) * 100;
  if(ErrorFlag == 0)
   {
     printf("\n\trp      = %.3f\n",Rp);
     printf("\trs      = %.3f\n",Rs);
     printf("\tl       = %.2f%%\n",L);

     fflush(stdin);
     printf("\nPress 'Return' to continue\n\n");
     scanf("%c", &x);
   }

}/*END Calculate_Fresnel*/
/*-----------------------------------------------------------------------------*/
