/*------------------------------------------------------------------------------
 *
 * Calculate_Kamb() - Called from Menu_H() -
 *                    1. Calls Report_Error() if the input data will result in
 *                       a negative square root.
 *                    2. Calculates '2V' for a mineral and determines the
 *                       interference figure using Kamb's Method.
 *                    3. When the calculation is complete, the values of all
 *                       variables are diplayed to the screen.  The display is
 *                       stopped from scrolling to allow the user to read the
 *                       results - the return key must be pressed to continue.
 *
 *------------------------------------------------------------------------------
 */

#include "opt_cal.h"
Calculate_Kamb(NA,Beta,SR)
double NA;                    /* numerical aperture of microscope lens         */
double Beta;                  /* approximate beta refractive index of material */
double SR;                    /* microscope stage rotation                     */
{
  char x;                      /* dummy scanning variable                      */
  double Temp1;                /* temporary variable                           */
  double Radian = 57.29577951; /* conversion from degrees to radians           */
  int ErrorFlag = 0;
  double Two_V;                /* calculated '2V' for a mineral                */
  extern Report_Error();
  extern double sqr();

  Temp1 = sin(2*SR/Radian) * (1/sqr(NA/Beta) - 0.5) + 0.5;

  if( Temp1 <= 0 )
   {
     Report_Error(29);
     ErrorFlag = 1;
   }

  else if( sqrt(1/Temp1) > 1)  Two_V = 200;

  else Two_V = Radian * 2 * asin(sqrt(1/Temp1));
  if(ErrorFlag == 0)
   {
     printf("\n\tNA             = %.2f\n", NA);
     printf("\tBeta           = %.4f\n", Beta);
     printf("\tStage rotation = %.1f\n\n", SR);

     if(Two_V < 90.0)
      {
        printf("\t2V             = %.1f\n",Two_V);
        printf("\tThe interference figure is  AB.\n");
      }
     else if(Two_V <= 180)
      {
        printf("\t2V             = %.1f\n",Two_V);
        printf("\tThe interference figure is  OB.\n");
      }
     else if(Two_V > 180)
      {
        printf("\t2V is imaginary ( > 180 ).\n");
        printf("\tThe interference figure is  ON.\n");
      }

     fflush(stdin);
     printf("\nPress 'Return' to continue\n\n");
     scanf("%c", &x);

   }
}/*END Calculate_Kamb */
/*-----------------------------------------------------------------------------*/

