/*------------------------------------------------------------------------------
 *
 * Calculate_Sellmeier() - Called from Menu_E() -
 *                         1. Calculates the refractive index of a material at
 *                            the given wavelength using the Linearized Sellmeier
 *                            equation.
 *                         2. Displays the refractive index and the given
 *                            wavelength to the screen.  The display is stopped
 *                            from scrolling to allow the user to read the
 *                            results - the return key must be pressed to
 *                            continue.
 *
 *------------------------------------------------------------------------------
 */

#include "opt_cal.h"
Calculate_Sellmeier(a0,a1,Lambda)
double a0;       /* material specific values for Sellmeier equation */
double a1;
double Lambda;   /* wavelength of light                             */
{
  char x;        /* dummy scanning variable                         */
  double n;      /* calculated refractive index                     */

  extern double sqr();
  extern Report_Error();


  if(     a0 + a1/sqr(Lambda)      == 0 ||
      1/( a0 + a1/sqr(Lambda)) + 1  < 0   )
    Report_Error(18);

  else
    n = sqrt( 1 /
              (a0 + a1/sqr(Lambda)) +
              1
            );

  if( n < 1.0 || n > 3.0 )
    Report_Error(17);

  else
   {
     printf("\n\tThe refractive index (n) = %.4f\n",n);
     printf("\tat the specified wavelength of %.2f nm.\n",Lambda);
     fflush(stdin);
     printf("\nPress 'Return' to continue\n\n");
     scanf("%c", &x);
   }

}/*END Calculate_Sellmeier*/
/*-----------------------------------------------------------------------------*/
