/*------------------------------------------------------------------------------
 *
 * Calculate_Snell() - Called from Menu_Snell() - 
 *                     1. Calls Report_Error() if the input data will result in 
 *                        an illegal 'Theta_incd' or Theta tran' or a zero 
 *                        denominator.
 *                     2. Calculates N_incd, N_tran, Theta_incd, or Theta_tran
 *                        depending on the value of SNchoice.
 *                     3. Calculates critical angle (Theta_ca) if N_incd > 
 *                        N_tran.
 *                     4. If no errors were detected, the values of all 
 *                        variables are displayed to the screen.  The display is
 *                        stopped from scrolling to allow the user to read the 
 *                        results - the return key must be pressed to continue.
 *
 *------------------------------------------------------------------------------
 */
 
#include "opt_cal.h"

Calculate_Snell(N_incd,N_tran,Theta_incd,Theta_tran,SNchoice)

double N_incd;       /* refractive index of incident material     */
double N_tran;       /* refractive index of transmitting material */
double Theta_incd;   /* angle of incidence                        */
double Theta_tran;   /* angle of transmittance (or refraction)    */
char SNchoice;       /* determines the variable to be solved for  */

{
  char x;                        /* dummy scanning variable            */
  int ErrorFlag = 0;
  double Radian = 57.29577951;   /* conversion from degrees to radians */
  
  double Theta_ca;               /* critical angle                     */
  
  extern Report_Error();
  
  switch(SNchoice)
  {
    case '1' : if(Theta_incd == 0) 
                {
                  Report_Error(10);
                  ErrorFlag = 1;
                 }
               else N_incd = N_tran * sin(Theta_tran/Radian) / 
                                      sin(Theta_incd/Radian);
               break;
               
    case '2' : if(Theta_tran == 0) 
                {
                  Report_Error(11);
                  ErrorFlag = 1;
                 }
               else N_tran = N_incd * sin(Theta_incd/Radian) / 
                                      sin(Theta_tran/Radian);
               break;

    case '3' : if(N_tran < N_incd)
                 Theta_incd = Radian * 
                              asin( N_tran*sin(Theta_tran/Radian) /
                                    N_incd 
                                  );
                                             
               else if( N_tran     >= N_incd  && 
                        Theta_tran <= Radian*asin(N_incd/N_tran)  )
                 Theta_incd = Radian * 
                              asin( N_tran*sin(Theta_tran/Radian) /
                                    N_incd 
                                  );
               else
                {
                  Report_Error(12);
                  ErrorFlag = 1;
                }
               break;

    case '4' : if(N_incd < N_tran)
                 Theta_tran = Radian * 
                              asin( N_incd*sin(Theta_incd/Radian) /
                                    N_tran 
                                  );
                                             
               else if( N_incd     >= N_tran  && 
                        Theta_incd <= Radian*asin(N_tran/N_incd)  )
                 Theta_tran = Radian * 
                              asin( N_incd*sin(Theta_incd/Radian) /
                                    N_tran 
                                  );
               else
                {
                  Report_Error(13);
                  ErrorFlag = 1;
                }
               break;
  }/*END SWITCH*/
  
  
  if(N_incd > N_tran) Theta_ca = Radian * asin(N_tran/N_incd);
  else Theta_ca = 90;
    
  if(ErrorFlag != 1)
   {
     printf("\n\tni             = %.4f\n",N_incd);
     printf("\tnt             = %.4f\n",N_tran);
     printf("\ttheta i        = %.2f\n",Theta_incd);
     
     if(Theta_tran > Theta_ca)
       printf("\ttheta t        = %.2f is past the critical angle\n",Theta_tran);
     else printf("\ttheta t        = %.2f\n",Theta_tran);
     
     if(N_incd > N_tran)
       printf("\tcritical angle = %.2f\n",Theta_ca);
     else printf("\t-> No critical angle. \n");

     fflush(stdin);
     printf("\nPress 'Return' to continue\n\n");
     scanf("%c", &x);
   }

}/*END Calculate_Snell*/
/*-----------------------------------------------------------------------------*/
