/*------------------------------------------------------------------------------
 *
 * Menu_B() - Called from main() - Diplays the menu for compensator plate
 *            equations and scans for user input.  Depending on user input
 *            Menu_B() will:
 *
 *            1.  Prompt the user to select a compensator plate material and
 *                enter input data.
 *                 a) For each value that is entered, Test_Inputs() is called
 *                    to ensure that it is a valid number.
 *                 b) Report_Error() is called to report an out of range
 *                    condition if any of the entered numbers fail the range
 *                    checking for this equation.
 *                 c) Calculate_Compensator() is called to perform the required
 *                    computation if all numerical values are good.
 *            2.  Call Report_Error() for invalid menu selection.
 *            3.  Exit and return to the main menu.
 *
 *------------------------------------------------------------------------------
 */
#include "opt_cal.h"
Menu_B()
{
  char Bchoice;          /* compensator menu selection variable */
  char Mchoice;          /* material menu selection variable    */
  char Bscan[20];        /* floating point scanning variable    */

  int  MenuFlag1;        /* menu selection flags                */
  int  MenuFlag2;

  double Thick;          /* compensator plate thickness */
  double Lambda;         /* wavelength of light         */
  double T_angle;        /* compensator tilt angle      */

  extern Report_Error();
  extern double Test_Inputs();
  extern Calculate_Compensator();

  do
  {
    Thick = MenuFlag1 = 1;
    Lambda = 500;
    T_angle = 45;
		  printf("\n\n\n\n\n\n\n\n\n\n\n\n\n\n");
		  printf("\tMenu B:  Compensator Plate Equations.\n\n");
		  printf("\tWhich type would you like?\n\n");
		  printf("\t(1) Berek.\n\n");
		  printf("\t(2) Ehringhaus.\n\n");
		  printf("\t(Q) Return to Main Menu.\n\n");
		  printf("\tEnter Selection and press 'Return':  ");
		
		  fflush(stdin);
		  scanf("%1c", &Bchoice);
		  fflush(stdin);
		
		  switch(Bchoice)
		  {
      case '1' :
      case '2' : do
                 {
                   MenuFlag2 = 1;
                   printf("\n\n\tWhich material would you like?\n\n");
																	  printf("\t(1) Quartz.\n\n");
																	  printf("\t(2) Calcite.\n\n");
																	  printf("\t(3) MAG.\n\n");
																	  printf("\tEnter Selection and press 'Return':  ");
																	
																	 fflush(stdin);
																	 scanf("%1c", &Mchoice);
																	 fflush(stdin);
																	 if(Mchoice != '1' && Mchoice != '2' && Mchoice != '3')
																	   {
																	     MenuFlag2 = 0;
																	     Report_Error(1);
																	   }
															  }while(MenuFlag2 == 0);
													
														   do
														   {
														     fflush(stdin);
														     printf("\n\n\tEnter plate thickness (mm) (nnn.n) -> ");
														     scanf("%20s", &Bscan);
														   }while( (Thick = Test_Inputs(Bscan)) == HUGE_VAL );
														
														   do
														   {
														     fflush(stdin);
														     printf("\tEnter Lambda (nm)          (nnn.n) -> ");
														     scanf("%20s", &Bscan);
														   }while( (Lambda = Test_Inputs(Bscan)) == HUGE_VAL );
																
														   do
														   {
														     fflush(stdin);
														     printf("\tEnter tilt angle (degrees) (nn.nn) -> ");
														     scanf("%20s", &Bscan);
														   }while( (T_angle = Test_Inputs(Bscan)) == HUGE_VAL );
		
		               break;
	
      case 'q' :
      case 'Q' : MenuFlag1 = 0;
		               printf("\n\nReturn to Main Menu.\n\n\n");
		               break;
		
		    default  : Report_Error(1);
		               MenuFlag1 = 0;
		               break;
	
	    }/*END SWITCH*/
	
	   if( Thick   <= 0.1   || Thick   >= 5.0 || Lambda  <=  300  ||
	       Lambda  >=  1200 || T_angle <= 0.0 || T_angle >= 90.0  )
	     Report_Error(5);
	
	   else if(MenuFlag1 != 0)
	     Calculate_Compensator(Thick,Lambda,T_angle,Bchoice,Mchoice);
  } while(Bchoice != 'q' && Bchoice != 'Q');

}/*END Menu_B*/
/*-----------------------------------------------------------------------------*/
