/*------------------------------------------------------------------------------
 *
 * Menu_D() - Called from main() - Diplays the menu for Snell's, Brewster's, and
 *            Fresnel's laws and scans for user input.  Depending on user input
 *            Menu_D() will:
 *
 *            1.  Call Menu_Snell() to handle Snell's Law.
 *            2.  Prompt the user and scan for input data for Brewster's or
 *                Fresnel's law via the switch-case statement.
 *                 a) For each value that is entered, Test_Inputs() is called
 *                    to ensure that it is a valid number.
 *                 b) Report_Error() is called to report an out of range
 *                    condition if any of the entered numbers fail the range
 *                    checking for this equation.
 *                 c) Calculate_Brewster() or Caculate_Fresnel() is called
 *                    as appropriate to perform the required computation if all
 *                    numerical values are good.
 *            3.  Call Report_Error() for invalid menu selection.
 *            4.  Exit and return to the main menu.
 *
 *------------------------------------------------------------------------------
 */
#include "opt_cal.h"
Menu_D()
{
  char Dchoice;          /* Menu choice scanning variable    */
  char Dscan[20];								/* floating point scanning variable */

  double N_incd;         /* incident material refractive index               */
  double N_tran;         /* transmitting material refractive index           */
  double Theta_incd;     /* angle of incident light                          */
  double Alpha;          /* angle between incident light and reflected light */

  extern Menu_Snell();
  extern Report_Error();
  extern Calculate_Fresnel();
  extern Calculate_Brewster();
  extern double Test_Inputs();

  do
  {
    N_incd = N_tran = Theta_incd = Alpha = 1;

		  printf("\n\n\n\n\n\n\n\n\n\n\n\n");
		  printf("\tMenu D:  Snell's, Brewster's, & Fresnel's Laws.\n\n");
		  printf("\tWhich would you like?\n\n");
		  printf("\t(1) Snell's Law.\n\n");
		  printf("\t(2) Brewster's Law.\n\n");
		  printf("\t(3) Fresnel's Law.\n\n");
		  printf("\t(Q) Return to Main Menu.\n\n");
		  printf("\tEnter Selection and press 'Return':  ");
		
		  fflush(stdin);
		  scanf("%1c", &Dchoice);
		  fflush(stdin);
		
		  switch(Dchoice)
		  {
		    case '1' : Menu_Snell();
                 break;

		    case '2' : do
		               {
		                fflush(stdin);
		                printf("\n\tEnter ni (n.nnnn) -> ");
		                scanf("%20s", &Dscan);
		               }while( (N_incd = Test_Inputs(Dscan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter nt (n.nnnn) -> ");
		                scanf("%20s", &Dscan);
		               }while( (N_tran = Test_Inputs(Dscan)) == HUGE_VAL );
		
		               if( N_incd <= 1.0 || N_incd >= 3.0 || N_tran <= 1.0 ||
		                   N_tran >= 3.0 || N_incd > N_tran  )
		                 Report_Error(8);
		
		               else Calculate_Brewster(N_incd,N_tran);
		               break;

		    case '3' : do
		               {
		                fflush(stdin);
		                printf("\n\tEnter ni      (n.nnnn) -> ");
		                scanf("%20s", &Dscan);
		               }while( (N_incd = Test_Inputs(Dscan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter nt      (n.nnnn) -> ");
		                scanf("%20s", &Dscan);
		               }while( (N_tran = Test_Inputs(Dscan)) == HUGE_VAL );
		
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter Theta i (nnn.nn) -> ");
		                scanf("%20s", &Dscan);
		               }while( (Theta_incd = Test_Inputs(Dscan)) == HUGE_VAL );
		
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter Alpha   (nnn.nn) -> ");
		                scanf("%20s", &Dscan);
		               }while( (Alpha = Test_Inputs(Dscan)) == HUGE_VAL );
		
		               if( N_incd*N_tran <= 1.0 || N_incd*N_tran >= 3.0  ||
		                   Theta_incd    < 0.0  || Theta_incd    > 90.0  ||
		                   Alpha         < 0.0  || Alpha         > 90.0 )
		                 Report_Error(9);
		
		               else Calculate_Fresnel(N_incd,N_tran,Theta_incd,Alpha);
		               break;

		    case 'q' :
		    case 'Q' : printf("\n\nReturn to Main Menu.\n\n\n");
		               break;
		
		    default  : Report_Error(1);
		               break;
		
		  }/*END SWTICH*/

 } while(Dchoice != 'q' && Dchoice != 'Q');

}/*END Menu_D*/
/*-----------------------------------------------------------------------------*/
