/*------------------------------------------------------------------------------
 *
 * Menu_E() - Called from main() - Diplays the menu Dispersion equations
 *            (Cauchy, Gunter and Linearized Sellmeier) and scans for user input.
 *            Depending on user input Menu_E() will:
 *
 *            1.  Prompt the user and scan for input data for the chosen equation
 *                via the switch-case statement.
 *                 a) For each value that is entered, Test_Inputs() is called
 *                    to ensure that it is a valid number.
 *                 b) Report_Error() is called to report an out of range
 *                    condition if any of the entered numbers fail the range
 *                    checking for this equation.
 *                 c) Calculate_Cauchy(), Caculate_Gunter(), or
 *                    Calculate_Sellmeieris called as appropriate to perform the
 *                    required computation if all numerical values are good.
 *            2.  Call Report_Error() for invalid menu selection.
 *            3.  Exit and return to the main menu.
 *
 *------------------------------------------------------------------------------
 */
#include "opt_cal.h"
Menu_E()
{
		char Echoice;    /* Menu choice scanning variable                   */
		char Escan[20];		/* floating point scanning variable                */
		
		double a0;       /* material specific values for Sellmeier equation */
		double a1;
		
		double b0;       /* material specific values for Gunter equation    */
		double b1;
		double b2;
		double b3;
		
		double C1;       /* material specific values for Cauchy equation    */
		double C2;
		double C3;
		
		double Lambda;   /* wavelength of light                             */
		
  extern Report_Error();
  extern Calculate_Cauchy();
  extern Calculate_Gunter();
  extern double Test_Inputs();
  extern Calculate_Sellmeier();

  do
   {
    printf("\n\n\n\n\n\n\n\n\n\n\n\n");
		  printf("\tMenu E:  Dispersion Equations.\n\n");
		  printf("\tWhich would you like to use?\n\n");
		  printf("\t(1) Cauchy.\n\n");
		  printf("\t(2) Gunter.\n\n");
		  printf("\t(3) Linearized Sellmeier.\n\n");
		  printf("\t(Q) Return to Main Menu.\n\n");
		  printf("\tEnter Selection and press 'Return':  ");
		
		  fflush(stdin);
		  scanf("%1c", &Echoice);
		  fflush(stdin);
		
		  switch(Echoice)
		  {
		    case '1' : printf("\n\tYou have selected the Cauchy equation:\n");
		               do
		               {
		                fflush(stdin);
		                printf("\n\tEnter C1           (n.nnnnnnnn) -> ");
		                scanf("%20s", &Escan);
		               }while( (C1 = Test_Inputs(Escan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter C2          (n.nnnnnnE-n) -> ");
		                scanf("%20s", &Escan);
		               }while( (C2 = Test_Inputs(Escan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter C3           (n.nnnnnnnn) -> ");
		                scanf("%20s", &Escan);
		               }while( (C3 = Test_Inputs(Escan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter lambda (microns) (nnn.nn) -> ");
		                scanf("%20s", &Escan);
		               }while( (Lambda = 1000*Test_Inputs(Escan)) == HUGE_VAL );
		
		               if( Lambda < 300 || Lambda > 1050 )
		                 Report_Error(16);
		
		               else  Calculate_Cauchy(C1,C2,C3,Lambda);
                 break;

		    case '2' : printf("\n\tYou have selected the Gunter equation:\n");
		               do
		               {
		                fflush(stdin);
		                printf("\n\tEnter b0      (n.nnnnnnnn) -> ");
		                scanf("%20s", &Escan);
		               }while( (b0 = Test_Inputs(Escan)) == HUGE_VAL );
		
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter b1     (n.nnnnnnE-n) -> ");
		                scanf("%20s", &Escan);
		               }while( (b1 = Test_Inputs(Escan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter b2      (n.nnnnnnnn) -> ");
		                scanf("%20s", &Escan);
		               }while( (b2 = Test_Inputs(Escan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter b3      (nnnn.nnnnn) -> ");
		                scanf("%20s", &Escan);
		               }while( (b3 = Test_Inputs(Escan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter lambda (nm) (nnn.nn) -> ");
		                scanf("%20s", &Escan);
		               }while( (Lambda = Test_Inputs(Escan)) == HUGE_VAL );
		
		               if( Lambda < 300 || Lambda > 1050 )
		                 Report_Error(16);
		
		               else Calculate_Gunter(b0,b1,b2,b3,Lambda);
		               break;

		    case '3' : printf("\n\tYou have selected the Linearized Sellmeier equation:\n");
		               do
		               {
		                fflush(stdin);
		                printf("\n\tEnter a0        (n.nnnnnn) -> ");
		                scanf("%20s", &Escan);
		               }while( (a0 = Test_Inputs(Escan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter a1         (nnnn.nn) -> ");
		                scanf("%20s", &Escan);
		               }while( (a1 = Test_Inputs(Escan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter lambda (nm) (nnn.nn) -> ");
		                scanf("%20s", &Escan);
		               }while( (Lambda = Test_Inputs(Escan)) == HUGE_VAL );
		
		               if( Lambda <= 300 || Lambda >= 1050 )
		                 Report_Error(16);
		
		               else Calculate_Sellmeier(a0,a1,Lambda);
		               break;

		    case 'q' :
		    case 'Q' : printf("\n\nReturn to Main Menu.\n\n\n");
		               break;
		
		    default  : Report_Error(1);
		               break;
		  }/*END SWTICH*/
   } while(Echoice != 'q' && Echoice != 'Q');
}/*END Menu_E()*/
/*-----------------------------------------------------------------------------*/
