/*------------------------------------------------------------------------------
 *
 * Menu_F() - Called from main() - Diplays the menu for performing Epsilon,
 *            Epsilon Prime, Omega, and Theta calculations and scans for user
 *            input.  Depending on user input Menu_F() will:
 *
 *            1.  Prompt the user and scan for the three remaining variables via
 *                the switch-case statement.
 *                 a) For each value that is entered, Test_Inputs() is called
 *                    to ensure that it is a valid number.
 *                 b) Report_Error() is called to report an out of range
 *                    condition if any of the entered numbers fail the range
 *                    checking for this equation.
 *                 c) Calculate_EEpOT() is called to perform the required
 *                    computation if all numerical values are good.
 *            2.  Call Report_Error() for invalid menu selection.
 *            3.  Exit and return to the main menu.
 *
 *------------------------------------------------------------------------------
 */
#include "opt_cal.h"
Menu_F()
{
  char Fchoice;               /* Menu choice scanning variable    */
  char Fscan[20];													/* floating point scanning variable */
  int  MenuFlag;              /* Menu selection flag              */

  double Epsilon;             /* long axis of ellipsoid                      */
  double Epsilon_P;           /* radius of ellipsoid at angle Theta          */
  double Omega;               /* short axis of ellipsoid                     */
  double Theta;               /* angle between Epsilon and and Epsilon Prime */
  extern Report_Error();
  extern Calculate_EEpOT();
  extern double Test_Inputs();
  do
  {
    Epsilon = Epsilon_P = Omega = Theta = MenuFlag = 2;

		  printf("\n\n\n\n\n\n\n\n\n\n\n");
		  printf("\tMenu F:  Epsilon, Epsilon Prime, ");
		  printf("Omega & Theta Calculations\n\n");
		  printf("\tWhich would you like to calculate?\n\n");
		  printf("\t(1) Epsilon.\n\n");
		  printf("\t(2) Epsilon Prime.\n\n");
		  printf("\t(3) Omega.\n\n");
		  printf("\t(4) Theta.\n\n");
		  printf("\t(Q) Return to Main Menu.\n\n");
		  printf("\tEnter Selection and press 'Return':  ");
		
		  fflush(stdin);
		  scanf("%1c", &Fchoice);
		  fflush(stdin);
		
		  switch(Fchoice)
		  {
		    case '1' : do
		               {
		                fflush(stdin);
		                printf("\n\tEnter Epsilon Prime (n.nnnn) -> ");
		                scanf("%20s", &Fscan);
		               }while( (Epsilon_P = Test_Inputs(Fscan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter Omega         (n.nnnn) -> ");
		                scanf("%20s", &Fscan);
		               }while( (Omega = Test_Inputs(Fscan)) == HUGE_VAL );
		
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter Theta          (nn.nn) -> ");
		                scanf("%20s", &Fscan);
		               }while( (Theta = Test_Inputs(Fscan)) == HUGE_VAL );
                 break;

		    case '2' : do
		               {
		                fflush(stdin);
		                printf("\n\tEnter Epsilon (n.nnnn) -> ");
		                scanf("%20s", &Fscan);
		               }while( (Epsilon = Test_Inputs(Fscan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter Omega   (n.nnnn) -> ");
		                scanf("%20s", &Fscan);
		               }while( (Omega = Test_Inputs(Fscan)) == HUGE_VAL );
		
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter Theta    (nn.nn) -> ");
		                scanf("%20s", &Fscan);
		               }while( (Theta = Test_Inputs(Fscan)) == HUGE_VAL );
                 break;

		    case '3' : do
		               {
		                fflush(stdin);
		                printf("\n\tEnter Epsilon       (n.nnnn) -> ");
		                scanf("%20s", &Fscan);
		               }while( (Epsilon = Test_Inputs(Fscan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter Epsilon Prime (n.nnnn) -> ");
		                scanf("%20s", &Fscan);
		               }while( (Epsilon_P = Test_Inputs(Fscan)) == HUGE_VAL );
		
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter Theta          (nn.nn) -> ");
		                scanf("%20s", &Fscan);
		               }while( (Theta = Test_Inputs(Fscan)) == HUGE_VAL );
                 break;

		    case '4' : do
		               {
		                fflush(stdin);
		                printf("\n\tEnter Epsilon       (n.nnnn) -> ");
		                scanf("%20s", &Fscan);
		               }while( (Epsilon = Test_Inputs(Fscan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter Epsilon Prime (n.nnnn) -> ");
		                scanf("%20s", &Fscan);
		               }while( (Epsilon_P = Test_Inputs(Fscan)) == HUGE_VAL );
		
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter Omega         (n.nnnn) -> ");
		                scanf("%20s", &Fscan);
		               }while( (Omega = Test_Inputs(Fscan)) == HUGE_VAL );
                 break;

		    case 'q' :
		    case 'Q' : MenuFlag = 0;
		               printf("\n\nReturn to Main Menu.\n\n\n");
		               break;
		
		    default  : Report_Error(1);
		               MenuFlag = 0;
		               break;
		  }/*END SWITCH*/

    if( Epsilon   <=  1 || Epsilon   >=  3 || Epsilon_P <=  1 ||
        Epsilon_P >=  3 || Omega     <=  1 || Omega     >=  3 ||
        Theta     <   0 || Theta     >  90 )
      Report_Error(20);

    else if(MenuFlag != 0) Calculate_EEpOT(Epsilon,Epsilon_P,Omega,Theta,Fchoice);
 } while(Fchoice != 'q' && Fchoice != 'Q');

}/*END Menu_F*/
/*-----------------------------------------------------------------------------*/
