/*------------------------------------------------------------------------------
 *
 * Menu_J() - Called from main() - Diplays the menu for performing Temperature
 *            corrections for refractive index liquids and scans for user input.
 *            Depending on user input Menu_J() will:
 *
 *            1.  Prompt the user for input data for a specific liquid.
 *                 a) For each value that is entered, Test_Inputs() is called
 *                    to ensure that it is a valid number.
 *                 b) Report_Error() is called to report an out of range
 *                    condition if any of the entered numbers fail the range
 *                    checking for this equation.
 *                 c) Calculate_Ref_Liquid() is called to perform the required
 *                    computation if all numerical values are good.
 *            2.  Call Report_Error() for invalid menu selection.
 *            3.  Exit and return to the main menu.
 *
 *------------------------------------------------------------------------------
 */
#include "opt_cal.h"
Menu_J()
{
  char Jchoice;          /* Menu choice scanning variable    */
  char Jscan[20];								/* floating point scanning variable */
  int  MenuFlag;         /* Menu selection flag              */

  double N_oil;     /* refractive index of liquid at T_bot                   */
  double T_bot;     /* temp at which N_oil is reported on bottle of liquid   */
  double T_room;    /* room temperature                                      */
  double dndt_bot;  /* change in refractive index with temp, given on bottle */

  extern Report_Error();
  extern double Test_Inputs();
  extern Calculate_Ref_Liquid();

  do
  {
    N_oil = T_bot = T_room = MenuFlag = 2;
    dndt_bot = 0.01;
		  printf("\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n");
		  printf("\tMenu J:  Temperature Corrections for Refractive Index Liquids.\n\n");
		  printf("\tWhich would you like?\n\n");
		  printf("\t(1) Enter refractive index liquid data.\n\n");
		  printf("\t(Q) Return to Main Menu.\n\n");
		  printf("\tEnter Selection and press 'Return':  ");
		
		  fflush(stdin);
		  scanf("%1c", &Jchoice);
		  fflush(stdin);
		
		  switch(Jchoice)
		  {
		    case '1' : printf("\n\tEnter the refractive index of the liquid, the\n");
		               printf("\ttemperature at which the index was determined,\n");
		               printf("\tthe change in index with temperature, (all three\n");
		               printf("\tof these are printed on the bottle) and\n");
		               printf("\troom temperature:\n");
		
		               do
		               {
		                fflush(stdin);
		                printf("\n\tEnter n_oil      (n.nnn) -> ");
		                scanf("%20s", &Jscan);
		               }while( (N_oil = Test_Inputs(Jscan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter T_bot       (nn.n) -> ");
		                scanf("%20s", &Jscan);
		               }while( (T_bot = Test_Inputs(Jscan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter dndt_bot (n.nnnnn) -> ");
		                scanf("%20s", &Jscan);
		               }while( (dndt_bot = Test_Inputs(Jscan)) == HUGE_VAL );
		
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter T_room      (nn.n) -> ");
		                scanf("%20s", &Jscan);
		               }while( (T_room = Test_Inputs(Jscan)) == HUGE_VAL );
                 break;

		    case 'q' :
		    case 'Q' : MenuFlag = 0;
		               printf("\n\nReturn to Main Menu.\n\n\n");
		               break;
		
		    default  : Report_Error(1);
		               MenuFlag = 0;
		               break;
		  }/*END SWITCH*/

    if( N_oil    <=   1.0     || N_oil    >=   3.0 || T_bot    <=   0.0 ||
        T_bot    >= 300.0     || T_room   <=   0.0 || T_room   >= 300.0 ||
        dndt_bot <=   0.00001 || dndt_bot >=   0.1 )
      Report_Error(32);

    else if(MenuFlag != 0)
      Calculate_Ref_Liquid(N_oil,T_bot,T_room,dndt_bot);

 } while(Jchoice != 'q' && Jchoice != 'Q');

}/*END Menu_J*/
/*-----------------------------------------------------------------------------*/
