/*------------------------------------------------------------------------------
 *
 * Test_Inputs() - Called by all Menu() routines -
 *                 1. Checks input string for any illegal characters.
 *                 2. Checks number of '+', '-', '.', 'e', and 'E' characters.
 *                 3. Checks strings with leading decimal point (illegal).
 *                 4. Compensates any input numbers that are < |1| by adding 1
 *                    since the 'C' routine atof() (converts strings to floating
 *                    point numbers) does not operate properly with numbers in
 *                    this range.
 *                 5. Checks for overflow/underflow.
 *                 6. Calls Report_Error() if any errors are detected.
 *                 7. Calls the 'C' library routine atof() if no errors are
 *                    detected to convert the input string to floating point and
 *                    this value is returned to the calling routine.
 *
 *------------------------------------------------------------------------------
 */
#include "opt_cal.h"
double Test_Inputs(Scan)
char Scan[];          /* character string form of floating point number  */
{
  double result;      /* floating point equivalent of input string       */
  char *nptr;         /* pointer to input string                         */
  int i = 0;
  int ErrorFlag = 0;
  int AddFlag   = 0;  /* flag for a "compensated" number (a 1 was added) */
  int Psign_cnt = 0;  /* number of '+' signs in the input string         */
  int Nsign_cnt = 0;  /* number of '-' signs in the input string         */
  int Dec_cnt   = 0;  /* number of decimal points in the input string    */
  int Exp_cnt   = 0;  /* number of exponential signs in the input string */

  extern Report_Error();

/*-------------------------Check for illegal characters------------------------*/

  nptr = &Scan[0];
  while(Scan[i] != '\0')
  {
    if( Scan[i] != 'e' && Scan[i] != 'E' && Scan[i] != '+' &&
        Scan[i] != '-' && Scan[i] != '.' && Scan[i] != '0' &&
        Scan[i] != '1' && Scan[i] != '2' && Scan[i] != '3' &&
        Scan[i] != '4' && Scan[i] != '5' && Scan[i] != '6' &&
        Scan[i] != '7' && Scan[i] != '8' && Scan[i] != '9'   )
      ErrorFlag = 1;

/*-----------------------Check for no. of legal symbols------------------------*/
    switch(Scan[i])
    {
      case '+' : Psign_cnt++; break;
      case '-' : Nsign_cnt++; break;
      case '.' : Dec_cnt++; break;
      case 'e' :
      case 'E' : Exp_cnt++; break;
    }

    i++;
  }/* END WHILE */

  if( Dec_cnt > 1 || Exp_cnt > 1 || Nsign_cnt + Psign_cnt > 2 )
    {
      ErrorFlag = 1;
      Report_Error(2);
      fflush(stdin);
    }

   if(Scan[0] == '.')
     ErrorFlag = 1;
   else if( (Scan[0] == '+' || Scan[0] == '-') && Scan[1] == '.')
          ErrorFlag = 1;
/*-----------Compensate numbers that are < |1| for the atof() routine----------*/
        else
	     {
	       i = 0;
	       if(Dec_cnt != 0 && Exp_cnt == 0)
	        {
	          while(Scan[i] != '.') i++;
	
	          if(Scan[i-1] == '0')
	            {
	              Scan[i-1] = Scan[i-1] + 1;
	              AddFlag = 1;
	            }
	        }
	       else if(Dec_cnt == 0 && Exp_cnt == 0)
	        {
	          while(Scan[i] != '\0') i++;
	
	          if(Scan[i-1] == '0')
	            {
	              Scan[i-1] = Scan[i-1] + 1;
	              AddFlag = 1;
	            }
	        }
	     }

  if(ErrorFlag == 0)
    {
      result = atof(nptr);

      if (result == HUGE_VAL || result == -HUGE_VAL)
        {
          result = HUGE_VAL;
          Report_Error(3);
          fflush(stdin);
        }
      else
        {
/*-----------------'uncompensate' any compensated numbers---------------------*/
          if(AddFlag == 1)
            {
              if(Nsign_cnt == 1) result = result + 1;
              else result = result - 1;
            }
        }
    }
  else
    {
      result = HUGE_VAL;
      Report_Error(2);
      fflush(stdin);
    }
  return(result);
}/*END Test_Inputs*/
/*-----------------------------------------------------------------------------*/
